<?php

class Mega_Lists
{
	public function __construct()
	{
		add_filter( 'mega_form_select_lists', array( $this, 'addList' ));
		add_filter( 'mega_cat_list', array( $this, 'catList' ));
		add_filter( 'mega_page_list', array( $this, 'pageList' ));
		add_filter( 'mega_post_list', array( $this, 'postList' ));
		add_filter( 'mega_fa_icon_list', array( $this, 'fontAwosome' ));
		add_filter( 'mega_ion_icon_list', array( $this, 'ionIcons' ));
		add_filter( 'mega_template_list', array( $this, 'templates' ));
		add_filter( 'mega_template_2_list', array( $this, 'templates2' ));
	}

	public function addList( $lists )
	{
		$lists['mega_cat_list']			= __( 'Category List', 'mega' );
		$lists['mega_page_list']		= __( 'Pages List', 'mega' );
		$lists['mega_post_list']		= __( 'Posts List', 'mega' );
		$lists['mega_fa_icon_list']		= __( 'Font Awosome Icon List', 'mega' );
		$lists['mega_ion_icon_list']	= __( 'IonIcons Icon List', 'mega' );
		$lists['mega_template_list']	= __( 'Template List', 'mega' );
		$lists['mega_template_2_list']	= __( 'Template List No Front / Home', 'mega' );

		return $lists;
	}

	public function catList()
	{
		$r[] = array( 'id' => 0, 'label' => __( 'All', 'mega' ));

		$this->buildSubjects( 'category', $r );

		return $r;
	}

	public function pageList()
	{
		$r[] = array( 'id' => 0, 'label' => __( 'All', 'mega' ));

		$this->buildSubjects( 'pages', $r );

		return $r;
	}

	public function postList()
	{
		$r[] = array( 'id' => 0, 'label' => __( 'All', 'mega' ));

		$this->buildSubjects( 'posts', $r );

		return $r;
	}

	public function buildSubjects( $type, &$r = array(), $id = 0 )
	{
		$args = array(
			'orderby'	=> 'count',
			'order'		=> 'DESC',
			'parent'	=> $id
		);

		switch( $type )
		{
			case 'category' :
				$subjects = get_categories( $args );
				break;

			case 'pages' :
				$subjects = get_pages( $args );
				break;

			case 'posts' :
				$subjects = get_posts( wp_parse_args( array( 'posts_per_page' => -1, 'post_parent' => $id ), $args ));
				break;
		}

		if ( $subjects && count( $subjects ) > 0 )
		{
			foreach( $subjects as $subject )
			{
				switch( $type )
				{
					case 'category' :
						$subject_id = $subject->term_id;
						$label		= $subject->name . ' (' . $subject->category_count . ')';
					break;

					case 'pages' :
						$subject_id = $subject->ID;
						$label		= $subject->post_title;
					break;

					case 'posts' :
						$subject_id = $subject->ID;
						$label		= $subject->post_title;
					break;
				}

				$r[] = array( 'id' => $subject_id, 'label' => $label, 'children' => false );

				end($r);

				$this->buildSubjects( $type, $r[key($r)]['children'], $subject_id );
			}
		}
	}

	public function templates()
	{
		return array(
			'front_page'				=> __( 'Front Page', 'mega' ),
			'category'					=> __( 'Category', 'mega' ),
			'archive'					=> __( 'Archive', 'mega' ),
			'search'					=> __( 'Search', 'mega' ),
			'post'						=> __( 'Post', 'mega' ),
			'template-home.php'			=> __( 'Template (Front Page)', 'mega' ),
			'template-onecolumn.php'	=> __( 'Template (Full Width)', 'mega' ),
			'template-login.php'		=> __( 'Template (Login)', 'mega' ),
			'template-contact.php'		=> __( 'Template (Contact)', 'mega' ),
			'page'						=> __( 'Page', 'mega' ),
			'home'						=> __( 'Blog', 'mega' )
		);
	}

	public function templates2()
	{
		global $mega_package;

		$r = $this->templates();

		if ( isset( $r['front_page'] ) && $mega_package == 0 )
			unset( $r['front_page'] );

		if ( isset( $r['home'] ) && $mega_package == 0 )
			unset( $r['home'] );

		return $r;
	}

	public function fontAwosome()
	{
		return array(
'' => __( 'None', 'mega' ),
'fa-adjust'=>'&#xf042;  adjust',
'fa-bomb'=>'&#xf1e2;  bomb',
'fa-share-alt-square'=>'&#xf1e1;  share-alt-square',
'fa-share-alt'=>'&#xf1e0;  share-alt',
'fa-sliders'=>'&#xf1de;  sliders',
'fa-paragraph'=>'&#xf1dd;  paragraph',
'fa-header'=>'&#xf1dc;  header',
'fa-circle-thin'=>'&#xf1db;  circle-thin',
'fa-history'=>'&#xf1da;  history',
'fa-paper-plane-o'=>'&#xf1d9;  paper-plane-o',
'fa-send-o'=>'&#xf1d9;  send-o (alias)',
'fa-paper-plane'=>'&#xf1d8;  paper-plane',
'fa-send'=>'&#xf1d8;  send (alias)',
'fa-wechat'=>'&#xf1d7;  wechat (alias)',
'fa-weixin'=>'&#xf1d7;  weixin',
'fa-qq'=>'&#xf1d6;  qq',
'fa-tencent-weibo'=>'&#xf1d5;  tencent-weibo',
'fa-hacker-news'=>'&#xf1d4;  hacker-news',
'fa-git'=>'&#xf1d3;  git',
'fa-git-square'=>'&#xf1d2;  git-square',
'fa-empire'=>'&#xf1d1;  empire',
'fa-ge'=>'&#xf1d1;  ge (alias)',
'fa-ra'=>'&#xf1d0;  ra (alias)',
'fa-rebel'=>'&#xf1d0;  rebel',
'fa-circle-o-notch'=>'&#xf1ce;  circle-o-notch',
'fa-life-bouy'=>'&#xf1cd;  life-bouy (alias)',
'fa-life-ring'=>'&#xf1cd;  life-ring',
'fa-life-saver'=>'&#xf1cd;  life-saver (alias)',
'fa-support'=>'&#xf1cd;  support (alias)',
'fa-jsfiddle'=>'&#xf1cc;  jsfiddle',
'fa-codepen'=>'&#xf1cb;  codepen',
'fa-vine'=>'&#xf1ca;  vine',
'fa-file-code-o'=>'&#xf1c9;  file-code-o',
'fa-file-movie-o'=>'&#xf1c8;  file-movie-o (alias)',
'fa-file-video-o'=>'&#xf1c8;  file-video-o',
'fa-file-audio-o'=>'&#xf1c7;  file-audio-o',
'fa-file-sound-o'=>'&#xf1c7;  file-sound-o (alias)',
'fa-file-archive-o'=>'&#xf1c6;  file-archive-o',
'fa-file-zip-o'=>'&#xf1c6;  file-zip-o (alias)',
'fa-file-image-o'=>'&#xf1c5;  file-image-o',
'fa-file-photo-o'=>'&#xf1c5;  file-photo-o (alias)',
'fa-file-picture-o'=>'&#xf1c5;  file-picture-o (alias)',
'fa-file-powerpoint-o'=>'&#xf1c4;  file-powerpoint-o',
'fa-file-excel-o'=>'&#xf1c3;  file-excel-o',
'fa-file-word-o'=>'&#xf1c2;  file-word-o',
'fa-file-pdf-o'=>'&#xf1c1;  file-pdf-o',
'fa-database'=>'&#xf1c0;  database',
'fa-soundcloud'=>'&#xf1be;  soundcloud',
'fa-deviantart'=>'&#xf1bd;  deviantart',
'fa-spotify'=>'&#xf1bc;  spotify',
'fa-tree'=>'&#xf1bb;  tree',
'fa-cab'=>'&#xf1ba;  cab (alias)',
'fa-taxi'=>'&#xf1ba;  taxi',
'fa-automobile'=>'&#xf1b9;  automobile (alias)',
'fa-car'=>'&#xf1b9;  car',
'fa-recycle'=>'&#xf1b8;  recycle',
'fa-steam-square'=>'&#xf1b7;  steam-square',
'fa-steam'=>'&#xf1b6;  steam',
'fa-behance-square'=>'&#xf1b5;  behance-square',
'fa-behance'=>'&#xf1b4;  behance',
'fa-cubes'=>'&#xf1b3;  cubes',
'fa-cube'=>'&#xf1b2;  cube',
'fa-spoon'=>'&#xf1b1;  spoon',
'fa-paw'=>'&#xf1b0;  paw',
'fa-child'=>'&#xf1ae;  child',
'fa-building'=>'&#xf1ad;  building',
'fa-fax'=>'&#xf1ac;  fax',
'fa-language'=>'&#xf1ab;  language',
'fa-joomla'=>'&#xf1aa;  joomla',
'fa-drupal'=>'&#xf1a9;  drupal',
'fa-pied-piper-alt'=>'&#xf1a8;  pied-piper-alt',
'fa-pied-piper'=>'&#xf1a7;  pied-piper',
'fa-pied-piper-square'=>'&#xf1a7;  pied-piper-square (alias)',
'fa-digg'=>'&#xf1a6;  digg',
'fa-delicious'=>'&#xf1a5;  delicious',
'fa-stumbleupon'=>'&#xf1a4;  stumbleupon',
'fa-stumbleupon-circle'=>'&#xf1a3;  stumbleupon-circle',
'fa-reddit-square'=>'&#xf1a2;  reddit-square',
'fa-reddit'=>'&#xf1a1;  reddit',
'fa-google'=>'&#xf1a0;  google',
'fa-yahoo'=>'&#xf19e;  yahoo',
'fa-graduation-cap'=>'&#xf19d;  graduation-cap',
'fa-mortar-board'=>'&#xf19d;  mortar-board (alias)',
'fa-bank'=>'&#xf19c;  bank (alias)',
'fa-institution'=>'&#xf19c;  institution (alias)',
'fa-university'=>'&#xf19c;  university',
'fa-openid'=>'&#xf19b;  openid',
'fa-wordpress'=>'&#xf19a;  wordpress',
'fa-envelope-square'=>'&#xf199;  envelope-square',
'fa-slack'=>'&#xf198;  slack',
'fa-space-shuttle'=>'&#xf197;  space-shuttle',
'fa-plus-square-o'=>'&#xf196;  plus-square-o',
'fa-try'=>'&#xf195;  try',
'fa-turkish-lira'=>'&#xf195;  turkish-lira (alias)',
'fa-vimeo-square'=>'&#xf194;  vimeo-square',
'fa-wheelchair'=>'&#xf193;  wheelchair',
'fa-dot-circle-o'=>'&#xf192;  dot-circle-o',
'fa-caret-square-o-left'=>'&#xf191;  caret-square-o-left',
'fa-toggle-left'=>'&#xf191;  toggle-left (alias)',
'fa-arrow-circle-o-left'=>'&#xf190;  arrow-circle-o-left',
'fa-arrow-circle-o-right'=>'&#xf18e;  arrow-circle-o-right',
'fa-stack-exchange'=>'&#xf18d;  stack-exchange',
'fa-pagelines'=>'&#xf18c;  pagelines',
'fa-renren'=>'&#xf18b;  renren',
'fa-weibo'=>'&#xf18a;  weibo',
'fa-vk'=>'&#xf189;  vk',
'fa-bug'=>'&#xf188;  bug',
'fa-archive'=>'&#xf187;  archive',
'fa-moon-o'=>'&#xf186;  moon-o',
'fa-sun-o'=>'&#xf185;  sun-o',
'fa-gittip'=>'&#xf184;  gittip',
'fa-male'=>'&#xf183;  male',
'fa-female'=>'&#xf182;  female',
'fa-trello'=>'&#xf181;  trello',
'fa-foursquare'=>'&#xf180;  foursquare',
'fa-skype'=>'&#xf17e;  skype',
'fa-dribbble'=>'&#xf17d;  dribbble',
'fa-linux'=>'&#xf17c;  linux',
'fa-android'=>'&#xf17b;  android',
'fa-windows'=>'&#xf17a;  windows',
'fa-apple'=>'&#xf179;  apple',
'fa-long-arrow-right'=>'&#xf178;  long-arrow-right',
'fa-long-arrow-left'=>'&#xf177;  long-arrow-left',
'fa-long-arrow-up'=>'&#xf176;  long-arrow-up',
'fa-long-arrow-down'=>'&#xf175;  long-arrow-down',
'fa-tumblr-square'=>'&#xf174;  tumblr-square',
'fa-tumblr'=>'&#xf173;  tumblr',
'fa-bitbucket-square'=>'&#xf172;  bitbucket-square',
'fa-bitbucket'=>'&#xf171;  bitbucket',
'fa-flickr'=>'&#xf16e;  flickr',
'fa-instagram'=>'&#xf16d;  instagram',
'fa-stack-overflow'=>'&#xf16c;  stack-overflow',
'fa-dropbox'=>'&#xf16b;  dropbox',
'fa-youtube-play'=>'&#xf16a;  youtube-play',
'fa-xing-square'=>'&#xf169;  xing-square',
'fa-xing'=>'&#xf168;  xing',
'fa-youtube'=>'&#xf167;  youtube',
'fa-youtube-square'=>'&#xf166;  youtube-square',
'fa-thumbs-down'=>'&#xf165;  thumbs-down',
'fa-thumbs-up'=>'&#xf164;  thumbs-up',
'fa-sort-numeric-desc'=>'&#xf163;  sort-numeric-desc',
'fa-sort-numeric-asc'=>'&#xf162;  sort-numeric-asc',
'fa-sort-amount-desc'=>'&#xf161;  sort-amount-desc',
'fa-sort-amount-asc'=>'&#xf160;  sort-amount-asc',
'fa-sort-alpha-desc'=>'&#xf15e;  sort-alpha-desc',
'fa-sort-alpha-asc'=>'&#xf15d;  sort-alpha-asc',
'fa-file-text'=>'&#xf15c;  file-text',
'fa-file'=>'&#xf15b;  file',
'fa-bitcoin'=>'&#xf15a;  bitcoin (alias)',
'fa-btc'=>'&#xf15a;  btc',
'fa-krw'=>'&#xf159;  krw',
'fa-won'=>'&#xf159;  won (alias)',
'fa-rouble'=>'&#xf158;  rouble (alias)',
'fa-rub'=>'&#xf158;  rub',
'fa-ruble'=>'&#xf158;  ruble (alias)',
'fa-cny'=>'&#xf157;  cny (alias)',
'fa-jpy'=>'&#xf157;  jpy',
'fa-rmb'=>'&#xf157;  rmb (alias)',
'fa-yen'=>'&#xf157;  yen (alias)',
'fa-inr'=>'&#xf156;  inr',
'fa-rupee'=>'&#xf156;  rupee (alias)',
'fa-dollar'=>'&#xf155;  dollar (alias)',
'fa-usd'=>'&#xf155;  usd',
'fa-gbp'=>'&#xf154;  gbp',
'fa-eur'=>'&#xf153;  eur',
'fa-euro'=>'&#xf153;  euro (alias)',
'fa-caret-square-o-right'=>'&#xf152;  caret-square-o-right',
'fa-toggle-right'=>'&#xf152;  toggle-right (alias)',
'fa-caret-square-o-up'=>'&#xf151;  caret-square-o-up',
'fa-toggle-up'=>'&#xf151;  toggle-up (alias)',
'fa-caret-square-o-down'=>'&#xf150;  caret-square-o-down',
'fa-toggle-down'=>'&#xf150;  toggle-down (alias)',
'fa-compass'=>'&#xf14e;  compass',
'fa-share-square'=>'&#xf14d;  share-square',
'fa-external-link-square'=>'&#xf14c;  external-link-square',
'fa-pencil-square'=>'&#xf14b;  pencil-square',
'fa-check-square'=>'&#xf14a;  check-square',
'fa-level-down'=>'&#xf149;  level-down',
'fa-level-up'=>'&#xf148;  level-up',
'fa-minus-square-o'=>'&#xf147;  minus-square-o',
'fa-minus-square'=>'&#xf146;  minus-square',
'fa-ticket'=>'&#xf145;  ticket',
'fa-play-circle'=>'&#xf144;  play-circle',
'fa-rss-square'=>'&#xf143;  rss-square',
'fa-ellipsis-v'=>'&#xf142;  ellipsis-v',
'fa-ellipsis-h'=>'&#xf141;  ellipsis-h',
'fa-bullseye'=>'&#xf140;  bullseye',
'fa-unlock-alt'=>'&#xf13e;  unlock-alt',
'fa-anchor'=>'&#xf13d;  anchor',
'fa-css3'=>'&#xf13c;  css3',
'fa-html5'=>'&#xf13b;  html5',
'fa-chevron-circle-down'=>'&#xf13a;  chevron-circle-down',
'fa-chevron-circle-up'=>'&#xf139;  chevron-circle-up',
'fa-chevron-circle-right'=>'&#xf138;  chevron-circle-right',
'fa-chevron-circle-left'=>'&#xf137;  chevron-circle-left',
'fa-maxcdn'=>'&#xf136;  maxcdn',
'fa-rocket'=>'&#xf135;  rocket',
'fa-fire-extinguisher'=>'&#xf134;  fire-extinguisher',
'fa-calendar-o'=>'&#xf133;  calendar-o',
'fa-shield'=>'&#xf132;  shield',
'fa-microphone-slash'=>'&#xf131;  microphone-slash',
'fa-microphone'=>'&#xf130;  microphone',
'fa-puzzle-piece'=>'&#xf12e;  puzzle-piece',
'fa-eraser'=>'&#xf12d;  eraser',
'fa-subscript'=>'&#xf12c;  subscript',
'fa-superscript'=>'&#xf12b;  superscript',
'fa-exclamation'=>'&#xf12a;  exclamation',
'fa-info'=>'&#xf129;  info',
'fa-question'=>'&#xf128;  question',
'fa-chain-broken'=>'&#xf127;  chain-broken',
'fa-unlink'=>'&#xf127;  unlink (alias)',
'fa-code-fork'=>'&#xf126;  code-fork',
'fa-crop'=>'&#xf125;  crop',
'fa-location-arrow'=>'&#xf124;  location-arrow',
'fa-star-half-empty'=>'&#xf123;  star-half-empty (alias)',
'fa-star-half-full'=>'&#xf123;  star-half-full (alias)',
'fa-star-half-o'=>'&#xf123;  star-half-o',
'fa-mail-reply-all'=>'&#xf122;  mail-reply-all (alias)',
'fa-reply-all'=>'&#xf122;  reply-all',
'fa-code'=>'&#xf121;  code',
'fa-terminal'=>'&#xf120;  terminal',
'fa-flag-checkered'=>'&#xf11e;  flag-checkered',
'fa-flag-o'=>'&#xf11d;  flag-o',
'fa-keyboard-o'=>'&#xf11c;  keyboard-o',
'fa-gamepad'=>'&#xf11b;  gamepad',
'fa-meh-o'=>'&#xf11a;  meh-o',
'fa-frown-o'=>'&#xf119;  frown-o',
'fa-smile-o'=>'&#xf118;  smile-o',
'fa-folder-open-o'=>'&#xf115;  folder-open-o',
'fa-folder-o'=>'&#xf114;  folder-o',
'fa-github-alt'=>'&#xf113;  github-alt',
'fa-mail-reply'=>'&#xf112;  mail-reply (alias)',
'fa-reply'=>'&#xf112;  reply',
'fa-circle'=>'&#xf111;  circle',
'fa-spinner'=>'&#xf110;  spinner',
'fa-quote-right'=>'&#xf10e;  quote-right',
'fa-quote-left'=>'&#xf10d;  quote-left',
'fa-circle-o'=>'&#xf10c;  circle-o',
'fa-mobile'=>'&#xf10b;  mobile',
'fa-mobile-phone'=>'&#xf10b;  mobile-phone (alias)',
'fa-tablet'=>'&#xf10a;  tablet',
'fa-laptop'=>'&#xf109;  laptop',
'fa-desktop'=>'&#xf108;  desktop',
'fa-angle-down'=>'&#xf107;  angle-down',
'fa-angle-up'=>'&#xf106;  angle-up',
'fa-angle-right'=>'&#xf105;  angle-right',
'fa-angle-left'=>'&#xf104;  angle-left',
'fa-angle-double-down'=>'&#xf103;  angle-double-down',
'fa-angle-double-up'=>'&#xf102;  angle-double-up',
'fa-angle-double-right'=>'&#xf101;  angle-double-right',
'fa-angle-double-left'=>'&#xf100;  angle-double-left',
'fa-plus-square'=>'&#xf0fe;  plus-square',
'fa-h-square'=>'&#xf0fd;  h-square',
'fa-beer'=>'&#xf0fc;  beer',
'fa-fighter-jet'=>'&#xf0fb;  fighter-jet',
'fa-medkit'=>'&#xf0fa;  medkit',
'fa-ambulance'=>'&#xf0f9;  ambulance',
'fa-hospital-o'=>'&#xf0f8;  hospital-o',
'fa-building-o'=>'&#xf0f7;  building-o',
'fa-file-text-o'=>'&#xf0f6;  file-text-o',
'fa-cutlery'=>'&#xf0f5;  cutlery',
'fa-coffee'=>'&#xf0f4;  coffee',
'fa-bell'=>'&#xf0f3;  bell',
'fa-suitcase'=>'&#xf0f2;  suitcase',
'fa-stethoscope'=>'&#xf0f1;  stethoscope',
'fa-user-md'=>'&#xf0f0;  user-md',
'fa-cloud-upload'=>'&#xf0ee;  cloud-upload',
'fa-cloud-download'=>'&#xf0ed;  cloud-download',
'fa-exchange'=>'&#xf0ec;  exchange',
'fa-lightbulb-o'=>'&#xf0eb;  lightbulb-o',
'fa-clipboard'=>'&#xf0ea;  clipboard',
'fa-paste'=>'&#xf0ea;  paste (alias)',
'fa-umbrella'=>'&#xf0e9;  umbrella',
'fa-sitemap'=>'&#xf0e8;  sitemap',
'fa-bolt'=>'&#xf0e7;  bolt',
'fa-flash'=>'&#xf0e7;  flash (alias)',
'fa-comments-o'=>'&#xf0e6;  comments-o',
'fa-comment-o'=>'&#xf0e5;  comment-o',
'fa-dashboard'=>'&#xf0e4;  dashboard (alias)',
'fa-tachometer'=>'&#xf0e4;  tachometer',
'fa-gavel'=>'&#xf0e3;  gavel',
'fa-legal'=>'&#xf0e3;  legal (alias)',
'fa-rotate-left'=>'&#xf0e2;  rotate-left (alias)',
'fa-undo'=>'&#xf0e2;  undo',
'fa-linkedin'=>'&#xf0e1;  linkedin',
'fa-envelope'=>'&#xf0e0;  envelope',
'fa-sort-asc'=>'&#xf0de;  sort-asc',
'fa-sort-up'=>'&#xf0de;  sort-up (alias)',
'fa-sort-desc'=>'&#xf0dd;  sort-desc',
'fa-sort-down'=>'&#xf0dd;  sort-down (alias)',
'fa-sort'=>'&#xf0dc;  sort',
'fa-unsorted'=>'&#xf0dc;  unsorted (alias)',
'fa-columns'=>'&#xf0db;  columns',
'fa-caret-right'=>'&#xf0da;  caret-right',
'fa-caret-left'=>'&#xf0d9;  caret-left',
'fa-caret-up'=>'&#xf0d8;  caret-up',
'fa-caret-down'=>'&#xf0d7;  caret-down',
'fa-money'=>'&#xf0d6;  money',
'fa-google-plus'=>'&#xf0d5;  google-plus',
'fa-google-plus-square'=>'&#xf0d4;  google-plus-square',
'fa-pinterest-square'=>'&#xf0d3;  pinterest-square',
'fa-pinterest'=>'&#xf0d2;  pinterest',
'fa-truck'=>'&#xf0d1;  truck',
'fa-magic'=>'&#xf0d0;  magic',
'fa-table'=>'&#xf0ce;  table',
'fa-underline'=>'&#xf0cd;  underline',
'fa-strikethrough'=>'&#xf0cc;  strikethrough',
'fa-list-ol'=>'&#xf0cb;  list-ol',
'fa-list-ul'=>'&#xf0ca;  list-ul',
'fa-bars'=>'&#xf0c9;  bars',
'fa-navicon'=>'&#xf0c9;  navicon (alias)',
'fa-reorder'=>'&#xf0c9;  reorder (alias)',
'fa-square'=>'&#xf0c8;  square',
'fa-floppy-o'=>'&#xf0c7;  floppy-o',
'fa-save'=>'&#xf0c7;  save (alias)',
'fa-paperclip'=>'&#xf0c6;  paperclip',
'fa-copy'=>'&#xf0c5;  copy (alias)',
'fa-files-o'=>'&#xf0c5;  files-o',
'fa-cut'=>'&#xf0c4;  cut (alias)',
'fa-scissors'=>'&#xf0c4;  scissors',
'fa-flask'=>'&#xf0c3;  flask',
'fa-cloud'=>'&#xf0c2;  cloud',
'fa-chain'=>'&#xf0c1;  chain (alias)',
'fa-link'=>'&#xf0c1;  link',
'fa-group'=>'&#xf0c0;  group (alias)',
'fa-users'=>'&#xf0c0;  users',
'fa-arrows-alt'=>'&#xf0b2;  arrows-alt',
'fa-briefcase'=>'&#xf0b1;  briefcase',
'fa-filter'=>'&#xf0b0;  filter',
'fa-tasks'=>'&#xf0ae;  tasks',
'fa-wrench'=>'&#xf0ad;  wrench',
'fa-globe'=>'&#xf0ac;  globe',
'fa-arrow-circle-down'=>'&#xf0ab;  arrow-circle-down',
'fa-arrow-circle-up'=>'&#xf0aa;  arrow-circle-up',
'fa-arrow-circle-right'=>'&#xf0a9;  arrow-circle-right',
'fa-arrow-circle-left'=>'&#xf0a8;  arrow-circle-left',
'fa-hand-o-down'=>'&#xf0a7;  hand-o-down',
'fa-hand-o-up'=>'&#xf0a6;  hand-o-up',
'fa-hand-o-left'=>'&#xf0a5;  hand-o-left',
'fa-hand-o-right'=>'&#xf0a4;  hand-o-right',
'fa-certificate'=>'&#xf0a3;  certificate',
'fa-bell-o'=>'&#xf0a2;  bell-o',
'fa-bullhorn'=>'&#xf0a1;  bullhorn',
'fa-hdd-o'=>'&#xf0a0;  hdd-o',
'fa-rss'=>'&#xf09e;  rss',
'fa-credit-card'=>'&#xf09d;  credit-card',
'fa-unlock'=>'&#xf09c;  unlock',
'fa-github'=>'&#xf09b;  github',
'fa-facebook'=>'&#xf09a;  facebook',
'fa-twitter'=>'&#xf099;  twitter',
'fa-phone-square'=>'&#xf098;  phone-square',
'fa-bookmark-o'=>'&#xf097;  bookmark-o',
'fa-square-o'=>'&#xf096;  square-o',
'fa-phone'=>'&#xf095;  phone',
'fa-lemon-o'=>'&#xf094;  lemon-o',
'fa-upload'=>'&#xf093;  upload',
'fa-github-square'=>'&#xf092;  github-square',
'fa-trophy'=>'&#xf091;  trophy',
'fa-sign-in'=>'&#xf090;  sign-in',
'fa-external-link'=>'&#xf08e;  external-link',
'fa-thumb-tack'=>'&#xf08d;  thumb-tack',
'fa-linkedin-square'=>'&#xf08c;  linkedin-square',
'fa-sign-out'=>'&#xf08b;  sign-out',
'fa-heart-o'=>'&#xf08a;  heart-o',
'fa-star-half'=>'&#xf089;  star-half',
'fa-thumbs-o-down'=>'&#xf088;  thumbs-o-down',
'fa-thumbs-o-up'=>'&#xf087;  thumbs-o-up',
'fa-comments'=>'&#xf086;  comments',
'fa-cogs'=>'&#xf085;  cogs',
'fa-gears'=>'&#xf085;  gears (alias)',
'fa-key'=>'&#xf084;  key',
'fa-camera-retro'=>'&#xf083;  camera-retro',
'fa-facebook-square'=>'&#xf082;  facebook-square',
'fa-twitter-square'=>'&#xf081;  twitter-square',
'fa-bar-chart-o'=>'&#xf080;  bar-chart-o',
'fa-arrows-h'=>'&#xf07e;  arrows-h',
'fa-arrows-v'=>'&#xf07d;  arrows-v',
'fa-folder-open'=>'&#xf07c;  folder-open',
'fa-folder'=>'&#xf07b;  folder',
'fa-shopping-cart'=>'&#xf07a;  shopping-cart',
'fa-retweet'=>'&#xf079;  retweet',
'fa-chevron-down'=>'&#xf078;  chevron-down',
'fa-chevron-up'=>'&#xf077;  chevron-up',
'fa-magnet'=>'&#xf076;  magnet',
'fa-comment'=>'&#xf075;  comment',
'fa-random'=>'&#xf074;  random',
'fa-calendar'=>'&#xf073;  calendar',
'fa-plane'=>'&#xf072;  plane',
'fa-exclamation-triangle'=>'&#xf071;  exclamation-triangle',
'fa-warning'=>'&#xf071;  warning (alias)',
'fa-eye-slash'=>'&#xf070;  eye-slash',
'fa-eye'=>'&#xf06e;  eye',
'fa-fire'=>'&#xf06d;  fire',
'fa-leaf'=>'&#xf06c;  leaf',
'fa-gift'=>'&#xf06b;  gift',
'fa-exclamation-circle'=>'&#xf06a;  exclamation-circle',
'fa-asterisk'=>'&#xf069;  asterisk',
'fa-minus'=>'&#xf068;  minus',
'fa-plus'=>'&#xf067;  plus',
'fa-compress'=>'&#xf066;  compress',
'fa-expand'=>'&#xf065;  expand',
'fa-mail-forward'=>'&#xf064;  mail-forward (alias)',
'fa-share'=>'&#xf064;  share',
'fa-arrow-down'=>'&#xf063;  arrow-down',
'fa-arrow-up'=>'&#xf062;  arrow-up',
'fa-arrow-right'=>'&#xf061;  arrow-right',
'fa-arrow-left'=>'&#xf060;  arrow-left',
'fa-ban'=>'&#xf05e;  ban',
'fa-check-circle-o'=>'&#xf05d;  check-circle-o',
'fa-times-circle-o'=>'&#xf05c;  times-circle-o',
'fa-crosshairs'=>'&#xf05b;  crosshairs',
'fa-info-circle'=>'&#xf05a;  info-circle',
'fa-question-circle'=>'&#xf059;  question-circle',
'fa-check-circle'=>'&#xf058;  check-circle',
'fa-times-circle'=>'&#xf057;  times-circle',
'fa-minus-circle'=>'&#xf056;  minus-circle',
'fa-plus-circle'=>'&#xf055;  plus-circle',
'fa-chevron-right'=>'&#xf054;  chevron-right',
'fa-chevron-left'=>'&#xf053;  chevron-left',
'fa-eject'=>'&#xf052;  eject',
'fa-step-forward'=>'&#xf051;  step-forward',
'fa-fast-forward'=>'&#xf050;  fast-forward',
'fa-forward'=>'&#xf04e;  forward',
'fa-stop'=>'&#xf04d;  stop',
'fa-pause'=>'&#xf04c;  pause',
'fa-play'=>'&#xf04b;  play',
'fa-backward'=>'&#xf04a;  backward',
'fa-fast-backward'=>'&#xf049;  fast-backward',
'fa-step-backward'=>'&#xf048;  step-backward',
'fa-arrows'=>'&#xf047;  arrows',
'fa-check-square-o'=>'&#xf046;  check-square-o',
'fa-share-square-o'=>'&#xf045;  share-square-o',
'fa-edit'=>'&#xf044;  edit (alias)',
'fa-pencil-square-o'=>'&#xf044;  pencil-square-o',
'fa-tint'=>'&#xf043;  tint',
'fa-map-marker'=>'&#xf041;  map-marker',
'fa-pencil'=>'&#xf040;  pencil',
'fa-image'=>'&#xf03e;  image (alias)',
'fa-photo'=>'&#xf03e;  photo (alias)',
'fa-picture-o'=>'&#xf03e;  picture-o',
'fa-video-camera'=>'&#xf03d;  video-camera',
'fa-indent'=>'&#xf03c;  indent',
'fa-dedent'=>'&#xf03b;  dedent (alias)',
'fa-outdent'=>'&#xf03b;  outdent',
'fa-list'=>'&#xf03a;  list',
'fa-align-justify'=>'&#xf039;  align-justify',
'fa-align-right'=>'&#xf038;  align-right',
'fa-align-center'=>'&#xf037;  align-center',
'fa-align-left'=>'&#xf036;  align-left',
'fa-text-width'=>'&#xf035;  text-width',
'fa-text-height'=>'&#xf034;  text-height',
'fa-italic'=>'&#xf033;  italic',
'fa-bold'=>'&#xf032;  bold',
'fa-font'=>'&#xf031;  font',
'fa-camera'=>'&#xf030;  camera',
'fa-print'=>'&#xf02f;  print',
'fa-bookmark'=>'&#xf02e;  bookmark',
'fa-book'=>'&#xf02d;  book',
'fa-tags'=>'&#xf02c;  tags',
'fa-tag'=>'&#xf02b;  tag',
'fa-barcode'=>'&#xf02a;  barcode',
'fa-qrcode'=>'&#xf029;  qrcode',
'fa-volume-up'=>'&#xf028;  volume-up',
'fa-volume-down'=>'&#xf027;  volume-down',
'fa-volume-off'=>'&#xf026;  volume-off',
'fa-headphones'=>'&#xf025;  headphones',
'fa-flag'=>'&#xf024;  flag',
'fa-lock'=>'&#xf023;  lock',
'fa-list-alt'=>'&#xf022;  list-alt',
'fa-refresh'=>'&#xf021;  refresh',
'fa-repeat'=>'&#xf01e;  repeat',
'fa-rotate-right'=>'&#xf01e;  rotate-right (alias)',
'fa-play-circle-o'=>'&#xf01d;  play-circle-o',
'fa-inbox'=>'&#xf01c;  inbox',
'fa-arrow-circle-o-up'=>'&#xf01b;  arrow-circle-o-up',
'fa-arrow-circle-o-down'=>'&#xf01a;  arrow-circle-o-down',
'fa-download'=>'&#xf019;  download',
'fa-road'=>'&#xf018;  road',
'fa-clock-o'=>'&#xf017;  clock-o',
'fa-file-o'=>'&#xf016;  file-o',
'fa-home'=>'&#xf015;  home',
'fa-trash-o'=>'&#xf014;  trash-o',
'fa-cog'=>'&#xf013;  cog',
'fa-gear'=>'&#xf013;  gear (alias)',
'fa-signal'=>'&#xf012;  signal',
'fa-power-off'=>'&#xf011;  power-off',
'fa-search-minus'=>'&#xf010;  search-minus',
'fa-search-plus'=>'&#xf00e;  search-plus',
'fa-times'=>'&#xf00d;  times',
'fa-check'=>'&#xf00c;  check',
'fa-th-list'=>'&#xf00b;  th-list',
'fa-th'=>'&#xf00a;  th',
'fa-th-large'=>'&#xf009;  th-large',
'fa-film'=>'&#xf008;  film',
'fa-user'=>'&#xf007;  user',
'fa-star-o'=>'&#xf006;  star-o',
'fa-star'=>'&#xf005;  star',
'fa-heart'=>'&#xf004;  heart',
'fa-envelope-o'=>'&#xf003;  envelope-o',
'fa-search'=>'&#xf002;  search',
'fa-music'=>'&#xf001;  music',
'fa-glass'=>'&#xf000;  glass',
'fa-adn'=>'&#xf170;  adn'

		);
	}

	public function ionIcons()
	{
		return array(
'' => __( 'None', 'mega' ),

'ion-alert'	=> '&#xf101;  ion-alert',
'ion-alert-circled'	=> '&#xf100;  ion-alert-circled',
'ion-android-add'	=> '&#xf2c7;  ion-android-add',
'ion-android-add-circle'	=> '&#xf359;  ion-android-add-circle',
'ion-android-alarm-clock'	=> '&#xf35a;  ion-android-alarm-clock',
'ion-android-alert'	=> '&#xf35b;  ion-android-alert',
'ion-android-apps'	=> '&#xf35c;  ion-android-apps',
'ion-android-archive'	=> '&#xf2c9;  ion-android-archive',
'ion-android-arrow-back'	=> '&#xf2ca;  ion-android-arrow-back',
'ion-android-arrow-down'	=> '&#xf35d;  ion-android-arrow-down',
'ion-android-arrow-dropdown'	=> '&#xf35f;  ion-android-arrow-dropdown',
'ion-android-arrow-dropdown-circle'	=> '&#xf35e;  ion-android-arrow-dropdown-circle',
'ion-android-arrow-dropleft'	=> '&#xf361;  ion-android-arrow-dropleft',
'ion-android-arrow-dropleft-circle'	=> '&#xf360;  ion-android-arrow-dropleft-circle',
'ion-android-arrow-dropright'	=> '&#xf363;  ion-android-arrow-dropright',
'ion-android-arrow-dropright-circle'	=> '&#xf362;  ion-android-arrow-dropright-circle',
'ion-android-arrow-dropup'	=> '&#xf365;  ion-android-arrow-dropup',
'ion-android-arrow-dropup-circle'	=> '&#xf364;  ion-android-arrow-dropup-circle',
'ion-android-arrow-forward'	=> '&#xf30f;  ion-android-arrow-forward',
'ion-android-arrow-up'	=> '&#xf366;  ion-android-arrow-up',
'ion-android-attach'	=> '&#xf367;  ion-android-attach',
'ion-android-bar'	=> '&#xf368;  ion-android-bar',
'ion-android-bicycle'	=> '&#xf369;  ion-android-bicycle',
'ion-android-boat'	=> '&#xf36a;  ion-android-boat',
'ion-android-bookmark'	=> '&#xf36b;  ion-android-bookmark',
'ion-android-bulb'	=> '&#xf36c;  ion-android-bulb',
'ion-android-bus'	=> '&#xf36d;  ion-android-bus',
'ion-android-calendar'	=> '&#xf2d1;  ion-android-calendar',
'ion-android-call'	=> '&#xf2d2;  ion-android-call',
'ion-android-camera'	=> '&#xf2d3;  ion-android-camera',
'ion-android-cancel'	=> '&#xf36e;  ion-android-cancel',
'ion-android-car'	=> '&#xf36f;  ion-android-car',
'ion-android-cart'	=> '&#xf370;  ion-android-cart',
'ion-android-chat'	=> '&#xf2d4;  ion-android-chat',
'ion-android-checkbox'	=> '&#xf374;  ion-android-checkbox',
'ion-android-checkbox-blank'	=> '&#xf371;  ion-android-checkbox-blank',
'ion-android-checkbox-outline'	=> '&#xf373;  ion-android-checkbox-outline',
'ion-android-checkbox-outline-blank'	=> '&#xf372;  ion-android-checkbox-outline-blank',
'ion-android-checkmark-circle'	=> '&#xf375;  ion-android-checkmark-circle',
'ion-android-clipboard'	=> '&#xf376;  ion-android-clipboard',
'ion-android-close'	=> '&#xf2d7;  ion-android-close',
'ion-android-cloud'	=> '&#xf37a;  ion-android-cloud',
'ion-android-cloud-circle'	=> '&#xf377;  ion-android-cloud-circle',
'ion-android-cloud-done'	=> '&#xf378;  ion-android-cloud-done',
'ion-android-cloud-outline'	=> '&#xf379;  ion-android-cloud-outline',
'ion-android-color-palette'	=> '&#xf37b;  ion-android-color-palette',
'ion-android-compass'	=> '&#xf37c;  ion-android-compass',
'ion-android-contact'	=> '&#xf2d8;  ion-android-contact',
'ion-android-contacts'	=> '&#xf2d9;  ion-android-contacts',
'ion-android-contract'	=> '&#xf37d;  ion-android-contract',
'ion-android-create'	=> '&#xf37e;  ion-android-create',
'ion-android-delete'	=> '&#xf37f;  ion-android-delete',
'ion-android-desktop'	=> '&#xf380;  ion-android-desktop',
'ion-android-document'	=> '&#xf381;  ion-android-document',
'ion-android-done'	=> '&#xf383;  ion-android-done',
'ion-android-done-all'	=> '&#xf382;  ion-android-done-all',
'ion-android-download'	=> '&#xf2dd;  ion-android-download',
'ion-android-drafts'	=> '&#xf384;  ion-android-drafts',
'ion-android-exit'	=> '&#xf385;  ion-android-exit',
'ion-android-expand'	=> '&#xf386;  ion-android-expand',
'ion-android-favorite'	=> '&#xf388;  ion-android-favorite',
'ion-android-favorite-outline'	=> '&#xf387;  ion-android-favorite-outline',
'ion-android-film'	=> '&#xf389;  ion-android-film',
'ion-android-folder'	=> '&#xf2e0;  ion-android-folder',
'ion-android-folder-open'	=> '&#xf38a;  ion-android-folder-open',
'ion-android-funnel'	=> '&#xf38b;  ion-android-funnel',
'ion-android-globe'	=> '&#xf38c;  ion-android-globe',
'ion-android-hand'	=> '&#xf2e3;  ion-android-hand',
'ion-android-hangout'	=> '&#xf38d;  ion-android-hangout',
'ion-android-happy'	=> '&#xf38e;  ion-android-happy',
'ion-android-home'	=> '&#xf38f;  ion-android-home',
'ion-android-image'	=> '&#xf2e4;  ion-android-image',
'ion-android-laptop'	=> '&#xf390;  ion-android-laptop',
'ion-android-list'	=> '&#xf391;  ion-android-list',
'ion-android-locate'	=> '&#xf2e9;  ion-android-locate',
'ion-android-lock'	=> '&#xf392;  ion-android-lock',
'ion-android-mail'	=> '&#xf2eb;  ion-android-mail',
'ion-android-map'	=> '&#xf393;  ion-android-map',
'ion-android-menu'	=> '&#xf394;  ion-android-menu',
'ion-android-microphone'	=> '&#xf2ec;  ion-android-microphone',
'ion-android-microphone-off'	=> '&#xf395;  ion-android-microphone-off',
'ion-android-more-horizontal'	=> '&#xf396;  ion-android-more-horizontal',
'ion-android-more-vertical'	=> '&#xf397;  ion-android-more-vertical',
'ion-android-navigate'	=> '&#xf398;  ion-android-navigate',
'ion-android-notifications'	=> '&#xf39b;  ion-android-notifications',
'ion-android-notifications-none'	=> '&#xf399;  ion-android-notifications-none',
'ion-android-notifications-off'	=> '&#xf39a;  ion-android-notifications-off',
'ion-android-open'	=> '&#xf39c;  ion-android-open',
'ion-android-options'	=> '&#xf39d;  ion-android-options',
'ion-android-people'	=> '&#xf39e;  ion-android-people',
'ion-android-person'	=> '&#xf3a0;  ion-android-person',
'ion-android-person-add'	=> '&#xf39f;  ion-android-person-add',
'ion-android-phone-landscape'	=> '&#xf3a1;  ion-android-phone-landscape',
'ion-android-phone-portrait'	=> '&#xf3a2;  ion-android-phone-portrait',
'ion-android-pin'	=> '&#xf3a3;  ion-android-pin',
'ion-android-plane'	=> '&#xf3a4;  ion-android-plane',
'ion-android-playstore'	=> '&#xf2f0;  ion-android-playstore',
'ion-android-print'	=> '&#xf3a5;  ion-android-print',
'ion-android-radio-button-off'	=> '&#xf3a6;  ion-android-radio-button-off',
'ion-android-radio-button-on'	=> '&#xf3a7;  ion-android-radio-button-on',
'ion-android-refresh'	=> '&#xf3a8;  ion-android-refresh',
'ion-android-remove'	=> '&#xf2f4;  ion-android-remove',
'ion-android-remove-circle'	=> '&#xf3a9;  ion-android-remove-circle',
'ion-android-restaurant'	=> '&#xf3aa;  ion-android-restaurant',
'ion-android-sad'	=> '&#xf3ab;  ion-android-sad',
'ion-android-search'	=> '&#xf2f5;  ion-android-search',
'ion-android-send'	=> '&#xf2f6;  ion-android-send',
'ion-android-settings'	=> '&#xf2f7;  ion-android-settings',
'ion-android-share'	=> '&#xf2f8;  ion-android-share',
'ion-android-share-alt'	=> '&#xf3ac;  ion-android-share-alt',
'ion-android-star'	=> '&#xf2fc;  ion-android-star',
'ion-android-star-half'	=> '&#xf3ad;  ion-android-star-half',
'ion-android-star-outline'	=> '&#xf3ae;  ion-android-star-outline',
'ion-android-stopwatch'	=> '&#xf2fd;  ion-android-stopwatch',
'ion-android-subway'	=> '&#xf3af;  ion-android-subway',
'ion-android-sunny'	=> '&#xf3b0;  ion-android-sunny',
'ion-android-sync'	=> '&#xf3b1;  ion-android-sync',
'ion-android-textsms'	=> '&#xf3b2;  ion-android-textsms',
'ion-android-time'	=> '&#xf3b3;  ion-android-time',
'ion-android-train'	=> '&#xf3b4;  ion-android-train',
'ion-android-unlock'	=> '&#xf3b5;  ion-android-unlock',
'ion-android-upload'	=> '&#xf3b6;  ion-android-upload',
'ion-android-volume-down'	=> '&#xf3b7;  ion-android-volume-down',
'ion-android-volume-mute'	=> '&#xf3b8;  ion-android-volume-mute',
'ion-android-volume-off'	=> '&#xf3b9;  ion-android-volume-off',
'ion-android-volume-up'	=> '&#xf3ba;  ion-android-volume-up',
'ion-android-walk'	=> '&#xf3bb;  ion-android-walk',
'ion-android-warning'	=> '&#xf3bc;  ion-android-warning',
'ion-android-watch'	=> '&#xf3bd;  ion-android-watch',
'ion-android-wifi'	=> '&#xf305;  ion-android-wifi',
'ion-aperture'	=> '&#xf313;  ion-aperture',
'ion-archive'	=> '&#xf102;  ion-archive',
'ion-arrow-down-a'	=> '&#xf103;  ion-arrow-down-a',
'ion-arrow-down-b'	=> '&#xf104;  ion-arrow-down-b',
'ion-arrow-down-c'	=> '&#xf105;  ion-arrow-down-c',
'ion-arrow-expand'	=> '&#xf25e;  ion-arrow-expand',
'ion-arrow-graph-down-left'	=> '&#xf25f;  ion-arrow-graph-down-left',
'ion-arrow-graph-down-right'	=> '&#xf260;  ion-arrow-graph-down-right',
'ion-arrow-graph-up-left'	=> '&#xf261;  ion-arrow-graph-up-left',
'ion-arrow-graph-up-right'	=> '&#xf262;  ion-arrow-graph-up-right',
'ion-arrow-left-a'	=> '&#xf106;  ion-arrow-left-a',
'ion-arrow-left-b'	=> '&#xf107;  ion-arrow-left-b',
'ion-arrow-left-c'	=> '&#xf108;  ion-arrow-left-c',
'ion-arrow-move'	=> '&#xf263;  ion-arrow-move',
'ion-arrow-resize'	=> '&#xf264;  ion-arrow-resize',
'ion-arrow-return-left'	=> '&#xf265;  ion-arrow-return-left',
'ion-arrow-return-right'	=> '&#xf266;  ion-arrow-return-right',
'ion-arrow-right-a'	=> '&#xf109;  ion-arrow-right-a',
'ion-arrow-right-b'	=> '&#xf10a;  ion-arrow-right-b',
'ion-arrow-right-c'	=> '&#xf10b;  ion-arrow-right-c',
'ion-arrow-shrink'	=> '&#xf267;  ion-arrow-shrink',
'ion-arrow-swap'	=> '&#xf268;  ion-arrow-swap',
'ion-arrow-up-a'	=> '&#xf10c;  ion-arrow-up-a',
'ion-arrow-up-b'	=> '&#xf10d;  ion-arrow-up-b',
'ion-arrow-up-c'	=> '&#xf10e;  ion-arrow-up-c',
'ion-asterisk'	=> '&#xf314;  ion-asterisk',
'ion-at'	=> '&#xf10f;  ion-at',
'ion-backspace'	=> '&#xf3bf;  ion-backspace',
'ion-backspace-outline'	=> '&#xf3be;  ion-backspace-outline',
'ion-bag'	=> '&#xf110;  ion-bag',
'ion-battery-charging'	=> '&#xf111;  ion-battery-charging',
'ion-battery-empty'	=> '&#xf112;  ion-battery-empty',
'ion-battery-full'	=> '&#xf113;  ion-battery-full',
'ion-battery-half'	=> '&#xf114;  ion-battery-half',
'ion-battery-low'	=> '&#xf115;  ion-battery-low',
'ion-beaker'	=> '&#xf269;  ion-beaker',
'ion-beer'	=> '&#xf26a;  ion-beer',
'ion-bluetooth'	=> '&#xf116;  ion-bluetooth',
'ion-bonfire'	=> '&#xf315;  ion-bonfire',
'ion-bookmark'	=> '&#xf26b;  ion-bookmark',
'ion-bowtie'	=> '&#xf3c0;  ion-bowtie',
'ion-briefcase'	=> '&#xf26c;  ion-briefcase',
'ion-bug'	=> '&#xf2be;  ion-bug',
'ion-calculator'	=> '&#xf26d;  ion-calculator',
'ion-calendar'	=> '&#xf117;  ion-calendar',
'ion-camera'	=> '&#xf118;  ion-camera',
'ion-card'	=> '&#xf119;  ion-card',
'ion-cash'	=> '&#xf316;  ion-cash',
'ion-chatbox'	=> '&#xf11b;  ion-chatbox',
'ion-chatbox-working'	=> '&#xf11a;  ion-chatbox-working',
'ion-chatboxes'	=> '&#xf11c;  ion-chatboxes',
'ion-chatbubble'	=> '&#xf11e;  ion-chatbubble',
'ion-chatbubble-working'	=> '&#xf11d;  ion-chatbubble-working',
'ion-chatbubbles'	=> '&#xf11f;  ion-chatbubbles',
'ion-checkmark'	=> '&#xf122;  ion-checkmark',
'ion-checkmark-circled'	=> '&#xf120;  ion-checkmark-circled',
'ion-checkmark-round'	=> '&#xf121;  ion-checkmark-round',
'ion-chevron-down'	=> '&#xf123;  ion-chevron-down',
'ion-chevron-left'	=> '&#xf124;  ion-chevron-left',
'ion-chevron-right'	=> '&#xf125;  ion-chevron-right',
'ion-chevron-up'	=> '&#xf126;  ion-chevron-up',
'ion-clipboard'	=> '&#xf127;  ion-clipboard',
'ion-clock'	=> '&#xf26e;  ion-clock',
'ion-close'	=> '&#xf12a;  ion-close',
'ion-close-circled'	=> '&#xf128;  ion-close-circled',
'ion-close-round'	=> '&#xf129;  ion-close-round',
'ion-closed-captioning'	=> '&#xf317;  ion-closed-captioning',
'ion-cloud'	=> '&#xf12b;  ion-cloud',
'ion-code'	=> '&#xf271;  ion-code',
'ion-code-download'	=> '&#xf26f;  ion-code-download',
'ion-code-working'	=> '&#xf270;  ion-code-working',
'ion-coffee'	=> '&#xf272;  ion-coffee',
'ion-compass'	=> '&#xf273;  ion-compass',
'ion-compose'	=> '&#xf12c;  ion-compose',
'ion-connection-bars'	=> '&#xf274;  ion-connection-bars',
'ion-contrast'	=> '&#xf275;  ion-contrast',
'ion-crop'	=> '&#xf3c1;  ion-crop',
'ion-cube'	=> '&#xf318;  ion-cube',
'ion-disc'	=> '&#xf12d;  ion-disc',
'ion-document'	=> '&#xf12f;  ion-document',
'ion-document-text'	=> '&#xf12e;  ion-document-text',
'ion-drag'	=> '&#xf130;  ion-drag',
'ion-earth'	=> '&#xf276;  ion-earth',
'ion-easel'	=> '&#xf3c2;  ion-easel',
'ion-edit'	=> '&#xf2bf;  ion-edit',
'ion-egg'	=> '&#xf277;  ion-egg',
'ion-eject'	=> '&#xf131;  ion-eject',
'ion-email'	=> '&#xf132;  ion-email',
'ion-email-unread'	=> '&#xf3c3;  ion-email-unread',
'ion-erlenmeyer-flask'	=> '&#xf3c5;  ion-erlenmeyer-flask',
'ion-erlenmeyer-flask-bubbles'	=> '&#xf3c4;  ion-erlenmeyer-flask-bubbles',
'ion-eye'	=> '&#xf133;  ion-eye',
'ion-eye-disabled'	=> '&#xf306;  ion-eye-disabled',
'ion-female'	=> '&#xf278;  ion-female',
'ion-filing'	=> '&#xf134;  ion-filing',
'ion-film-marker'	=> '&#xf135;  ion-film-marker',
'ion-fireball'	=> '&#xf319;  ion-fireball',
'ion-flag'	=> '&#xf279;  ion-flag',
'ion-flame'	=> '&#xf31a;  ion-flame',
'ion-flash'	=> '&#xf137;  ion-flash',
'ion-flash-off'	=> '&#xf136;  ion-flash-off',
'ion-folder'	=> '&#xf139;  ion-folder',
'ion-fork'	=> '&#xf27a;  ion-fork',
'ion-fork-repo'	=> '&#xf2c0;  ion-fork-repo',
'ion-forward'	=> '&#xf13a;  ion-forward',
'ion-funnel'	=> '&#xf31b;  ion-funnel',
'ion-gear-a'	=> '&#xf13d;  ion-gear-a',
'ion-gear-b'	=> '&#xf13e;  ion-gear-b',
'ion-grid'	=> '&#xf13f;  ion-grid',
'ion-hammer'	=> '&#xf27b;  ion-hammer',
'ion-happy'	=> '&#xf31c;  ion-happy',
'ion-happy-outline'	=> '&#xf3c6;  ion-happy-outline',
'ion-headphone'	=> '&#xf140;  ion-headphone',
'ion-heart'	=> '&#xf141;  ion-heart',
'ion-heart-broken'	=> '&#xf31d;  ion-heart-broken',
'ion-help'	=> '&#xf143;  ion-help',
'ion-help-buoy'	=> '&#xf27c;  ion-help-buoy',
'ion-help-circled'	=> '&#xf142;  ion-help-circled',
'ion-home'	=> '&#xf144;  ion-home',
'ion-icecream'	=> '&#xf27d;  ion-icecream',
'ion-image'	=> '&#xf147;  ion-image',
'ion-images'	=> '&#xf148;  ion-images',
'ion-information'	=> '&#xf14a;  ion-information',
'ion-information-circled'	=> '&#xf149;  ion-information-circled',
'ion-ionic'	=> '&#xf14b;  ion-ionic',
'ion-ios-alarm'	=> '&#xf3c8;  ion-ios-alarm',
'ion-ios-alarm-outline'	=> '&#xf3c7;  ion-ios-alarm-outline',
'ion-ios-albums'	=> '&#xf3ca;  ion-ios-albums',
'ion-ios-albums-outline'	=> '&#xf3c9;  ion-ios-albums-outline',
'ion-ios-americanfootball'	=> '&#xf3cc;  ion-ios-americanfootball',
'ion-ios-americanfootball-outline'	=> '&#xf3cb;  ion-ios-americanfootball-outline',
'ion-ios-analytics'	=> '&#xf3ce;  ion-ios-analytics',
'ion-ios-analytics-outline'	=> '&#xf3cd;  ion-ios-analytics-outline',
'ion-ios-arrow-back'	=> '&#xf3cf;  ion-ios-arrow-back',
'ion-ios-arrow-down'	=> '&#xf3d0;  ion-ios-arrow-down',
'ion-ios-arrow-forward'	=> '&#xf3d1;  ion-ios-arrow-forward',
'ion-ios-arrow-left'	=> '&#xf3d2;  ion-ios-arrow-left',
'ion-ios-arrow-right'	=> '&#xf3d3;  ion-ios-arrow-right',
'ion-ios-arrow-thin-down'	=> '&#xf3d4;  ion-ios-arrow-thin-down',
'ion-ios-arrow-thin-left'	=> '&#xf3d5;  ion-ios-arrow-thin-left',
'ion-ios-arrow-thin-right'	=> '&#xf3d6;  ion-ios-arrow-thin-right',
'ion-ios-arrow-thin-up'	=> '&#xf3d7;  ion-ios-arrow-thin-up',
'ion-ios-arrow-up'	=> '&#xf3d8;  ion-ios-arrow-up',
'ion-ios-at'	=> '&#xf3da;  ion-ios-at',
'ion-ios-at-outline'	=> '&#xf3d9;  ion-ios-at-outline',
'ion-ios-barcode'	=> '&#xf3dc;  ion-ios-barcode',
'ion-ios-barcode-outline'	=> '&#xf3db;  ion-ios-barcode-outline',
'ion-ios-baseball'	=> '&#xf3de;  ion-ios-baseball',
'ion-ios-baseball-outline'	=> '&#xf3dd;  ion-ios-baseball-outline',
'ion-ios-basketball'	=> '&#xf3e0;  ion-ios-basketball',
'ion-ios-basketball-outline'	=> '&#xf3df;  ion-ios-basketball-outline',
'ion-ios-bell'	=> '&#xf3e2;  ion-ios-bell',
'ion-ios-bell-outline'	=> '&#xf3e1;  ion-ios-bell-outline',
'ion-ios-body'	=> '&#xf3e4;  ion-ios-body',
'ion-ios-body-outline'	=> '&#xf3e3;  ion-ios-body-outline',
'ion-ios-bolt'	=> '&#xf3e6;  ion-ios-bolt',
'ion-ios-bolt-outline'	=> '&#xf3e5;  ion-ios-bolt-outline',
'ion-ios-book'	=> '&#xf3e8;  ion-ios-book',
'ion-ios-book-outline'	=> '&#xf3e7;  ion-ios-book-outline',
'ion-ios-bookmarks'	=> '&#xf3ea;  ion-ios-bookmarks',
'ion-ios-bookmarks-outline'	=> '&#xf3e9;  ion-ios-bookmarks-outline',
'ion-ios-box'	=> '&#xf3ec;  ion-ios-box',
'ion-ios-box-outline'	=> '&#xf3eb;  ion-ios-box-outline',
'ion-ios-briefcase'	=> '&#xf3ee;  ion-ios-briefcase',
'ion-ios-briefcase-outline'	=> '&#xf3ed;  ion-ios-briefcase-outline',
'ion-ios-browsers'	=> '&#xf3f0;  ion-ios-browsers',
'ion-ios-browsers-outline'	=> '&#xf3ef;  ion-ios-browsers-outline',
'ion-ios-calculator'	=> '&#xf3f2;  ion-ios-calculator',
'ion-ios-calculator-outline'	=> '&#xf3f1;  ion-ios-calculator-outline',
'ion-ios-calendar'	=> '&#xf3f4;  ion-ios-calendar',
'ion-ios-calendar-outline'	=> '&#xf3f3;  ion-ios-calendar-outline',
'ion-ios-camera'	=> '&#xf3f6;  ion-ios-camera',
'ion-ios-camera-outline'	=> '&#xf3f5;  ion-ios-camera-outline',
'ion-ios-cart'	=> '&#xf3f8;  ion-ios-cart',
'ion-ios-cart-outline'	=> '&#xf3f7;  ion-ios-cart-outline',
'ion-ios-chatboxes'	=> '&#xf3fa;  ion-ios-chatboxes',
'ion-ios-chatboxes-outline'	=> '&#xf3f9;  ion-ios-chatboxes-outline',
'ion-ios-chatbubble'	=> '&#xf3fc;  ion-ios-chatbubble',
'ion-ios-chatbubble-outline'	=> '&#xf3fb;  ion-ios-chatbubble-outline',
'ion-ios-checkmark'	=> '&#xf3ff;  ion-ios-checkmark',
'ion-ios-checkmark-empty'	=> '&#xf3fd;  ion-ios-checkmark-empty',
'ion-ios-checkmark-outline'	=> '&#xf3fe;  ion-ios-checkmark-outline',
'ion-ios-circle-filled'	=> '&#xf400;  ion-ios-circle-filled',
'ion-ios-circle-outline'	=> '&#xf401;  ion-ios-circle-outline',
'ion-ios-clock'	=> '&#xf403;  ion-ios-clock',
'ion-ios-clock-outline'	=> '&#xf402;  ion-ios-clock-outline',
'ion-ios-close'	=> '&#xf406;  ion-ios-close',
'ion-ios-close-empty'	=> '&#xf404;  ion-ios-close-empty',
'ion-ios-close-outline'	=> '&#xf405;  ion-ios-close-outline',
'ion-ios-cloud'	=> '&#xf40c;  ion-ios-cloud',
'ion-ios-cloud-download'	=> '&#xf408;  ion-ios-cloud-download',
'ion-ios-cloud-download-outline'	=> '&#xf407;  ion-ios-cloud-download-outline',
'ion-ios-cloud-outline'	=> '&#xf409;  ion-ios-cloud-outline',
'ion-ios-cloud-upload'	=> '&#xf40b;  ion-ios-cloud-upload',
'ion-ios-cloud-upload-outline'	=> '&#xf40a;  ion-ios-cloud-upload-outline',
'ion-ios-cloudy'	=> '&#xf410;  ion-ios-cloudy',
'ion-ios-cloudy-night'	=> '&#xf40e;  ion-ios-cloudy-night',
'ion-ios-cloudy-night-outline'	=> '&#xf40d;  ion-ios-cloudy-night-outline',
'ion-ios-cloudy-outline'	=> '&#xf40f;  ion-ios-cloudy-outline',
'ion-ios-cog'	=> '&#xf412;  ion-ios-cog',
'ion-ios-cog-outline'	=> '&#xf411;  ion-ios-cog-outline',
'ion-ios-color-filter'	=> '&#xf414;  ion-ios-color-filter',
'ion-ios-color-filter-outline'	=> '&#xf413;  ion-ios-color-filter-outline',
'ion-ios-color-wand'	=> '&#xf416;  ion-ios-color-wand',
'ion-ios-color-wand-outline'	=> '&#xf415;  ion-ios-color-wand-outline',
'ion-ios-compose'	=> '&#xf418;  ion-ios-compose',
'ion-ios-compose-outline'	=> '&#xf417;  ion-ios-compose-outline',
'ion-ios-contact'	=> '&#xf41a;  ion-ios-contact',
'ion-ios-contact-outline'	=> '&#xf419;  ion-ios-contact-outline',
'ion-ios-copy'	=> '&#xf41c;  ion-ios-copy',
'ion-ios-copy-outline'	=> '&#xf41b;  ion-ios-copy-outline',
'ion-ios-crop'	=> '&#xf41e;  ion-ios-crop',
'ion-ios-crop-strong'	=> '&#xf41d;  ion-ios-crop-strong',
'ion-ios-download'	=> '&#xf420;  ion-ios-download',
'ion-ios-download-outline'	=> '&#xf41f;  ion-ios-download-outline',
'ion-ios-drag'	=> '&#xf421;  ion-ios-drag',
'ion-ios-email'	=> '&#xf423;  ion-ios-email',
'ion-ios-email-outline'	=> '&#xf422;  ion-ios-email-outline',
'ion-ios-eye'	=> '&#xf425;  ion-ios-eye',
'ion-ios-eye-outline'	=> '&#xf424;  ion-ios-eye-outline',
'ion-ios-fastforward'	=> '&#xf427;  ion-ios-fastforward',
'ion-ios-fastforward-outline'	=> '&#xf426;  ion-ios-fastforward-outline',
'ion-ios-filing'	=> '&#xf429;  ion-ios-filing',
'ion-ios-filing-outline'	=> '&#xf428;  ion-ios-filing-outline',
'ion-ios-film'	=> '&#xf42b;  ion-ios-film',
'ion-ios-film-outline'	=> '&#xf42a;  ion-ios-film-outline',
'ion-ios-flag'	=> '&#xf42d;  ion-ios-flag',
'ion-ios-flag-outline'	=> '&#xf42c;  ion-ios-flag-outline',
'ion-ios-flame'	=> '&#xf42f;  ion-ios-flame',
'ion-ios-flame-outline'	=> '&#xf42e;  ion-ios-flame-outline',
'ion-ios-flask'	=> '&#xf431;  ion-ios-flask',
'ion-ios-flask-outline'	=> '&#xf430;  ion-ios-flask-outline',
'ion-ios-flower'	=> '&#xf433;  ion-ios-flower',
'ion-ios-flower-outline'	=> '&#xf432;  ion-ios-flower-outline',
'ion-ios-folder'	=> '&#xf435;  ion-ios-folder',
'ion-ios-folder-outline'	=> '&#xf434;  ion-ios-folder-outline',
'ion-ios-football'	=> '&#xf437;  ion-ios-football',
'ion-ios-football-outline'	=> '&#xf436;  ion-ios-football-outline',
'ion-ios-game-controller-a'	=> '&#xf439;  ion-ios-game-controller-a',
'ion-ios-game-controller-a-outline'	=> '&#xf438;  ion-ios-game-controller-a-outline',
'ion-ios-game-controller-b'	=> '&#xf43b;  ion-ios-game-controller-b',
'ion-ios-game-controller-b-outline'	=> '&#xf43a;  ion-ios-game-controller-b-outline',
'ion-ios-gear'	=> '&#xf43d;  ion-ios-gear',
'ion-ios-gear-outline'	=> '&#xf43c;  ion-ios-gear-outline',
'ion-ios-glasses'	=> '&#xf43f;  ion-ios-glasses',
'ion-ios-glasses-outline'	=> '&#xf43e;  ion-ios-glasses-outline',
'ion-ios-grid-view'	=> '&#xf441;  ion-ios-grid-view',
'ion-ios-grid-view-outline'	=> '&#xf440;  ion-ios-grid-view-outline',
'ion-ios-heart'	=> '&#xf443;  ion-ios-heart',
'ion-ios-heart-outline'	=> '&#xf442;  ion-ios-heart-outline',
'ion-ios-help'	=> '&#xf446;  ion-ios-help',
'ion-ios-help-empty'	=> '&#xf444;  ion-ios-help-empty',
'ion-ios-help-outline'	=> '&#xf445;  ion-ios-help-outline',
'ion-ios-home'	=> '&#xf448;  ion-ios-home',
'ion-ios-home-outline'	=> '&#xf447;  ion-ios-home-outline',
'ion-ios-infinite'	=> '&#xf44a;  ion-ios-infinite',
'ion-ios-infinite-outline'	=> '&#xf449;  ion-ios-infinite-outline',
'ion-ios-information'	=> '&#xf44d;  ion-ios-information',
'ion-ios-information-empty'	=> '&#xf44b;  ion-ios-information-empty',
'ion-ios-information-outline'	=> '&#xf44c;  ion-ios-information-outline',
'ion-ios-ionic-outline'	=> '&#xf44e;  ion-ios-ionic-outline',
'ion-ios-keypad'	=> '&#xf450;  ion-ios-keypad',
'ion-ios-keypad-outline'	=> '&#xf44f;  ion-ios-keypad-outline',
'ion-ios-lightbulb'	=> '&#xf452;  ion-ios-lightbulb',
'ion-ios-lightbulb-outline'	=> '&#xf451;  ion-ios-lightbulb-outline',
'ion-ios-list'	=> '&#xf454;  ion-ios-list',
'ion-ios-list-outline'	=> '&#xf453;  ion-ios-list-outline',
'ion-ios-location'	=> '&#xf456;  ion-ios-location',
'ion-ios-location-outline'	=> '&#xf455;  ion-ios-location-outline',
'ion-ios-locked'	=> '&#xf458;  ion-ios-locked',
'ion-ios-locked-outline'	=> '&#xf457;  ion-ios-locked-outline',
'ion-ios-loop'	=> '&#xf45a;  ion-ios-loop',
'ion-ios-loop-strong'	=> '&#xf459;  ion-ios-loop-strong',
'ion-ios-medical'	=> '&#xf45c;  ion-ios-medical',
'ion-ios-medical-outline'	=> '&#xf45b;  ion-ios-medical-outline',
'ion-ios-medkit'	=> '&#xf45e;  ion-ios-medkit',
'ion-ios-medkit-outline'	=> '&#xf45d;  ion-ios-medkit-outline',
'ion-ios-mic'	=> '&#xf461;  ion-ios-mic',
'ion-ios-mic-off'	=> '&#xf45f;  ion-ios-mic-off',
'ion-ios-mic-outline'	=> '&#xf460;  ion-ios-mic-outline',
'ion-ios-minus'	=> '&#xf464;  ion-ios-minus',
'ion-ios-minus-empty'	=> '&#xf462;  ion-ios-minus-empty',
'ion-ios-minus-outline'	=> '&#xf463;  ion-ios-minus-outline',
'ion-ios-monitor'	=> '&#xf466;  ion-ios-monitor',
'ion-ios-monitor-outline'	=> '&#xf465;  ion-ios-monitor-outline',
'ion-ios-moon'	=> '&#xf468;  ion-ios-moon',
'ion-ios-moon-outline'	=> '&#xf467;  ion-ios-moon-outline',
'ion-ios-more'	=> '&#xf46a;  ion-ios-more',
'ion-ios-more-outline'	=> '&#xf469;  ion-ios-more-outline',
'ion-ios-musical-note'	=> '&#xf46b;  ion-ios-musical-note',
'ion-ios-musical-notes'	=> '&#xf46c;  ion-ios-musical-notes',
'ion-ios-navigate'	=> '&#xf46e;  ion-ios-navigate',
'ion-ios-navigate-outline'	=> '&#xf46d;  ion-ios-navigate-outline',
'ion-ios-nutrition'	=> '&#xf470;  ion-ios-nutrition',
'ion-ios-nutrition-outline'	=> '&#xf46f;  ion-ios-nutrition-outline',
'ion-ios-paper'	=> '&#xf472;  ion-ios-paper',
'ion-ios-paper-outline'	=> '&#xf471;  ion-ios-paper-outline',
'ion-ios-paperplane'	=> '&#xf474;  ion-ios-paperplane',
'ion-ios-paperplane-outline'	=> '&#xf473;  ion-ios-paperplane-outline',
'ion-ios-partlysunny'	=> '&#xf476;  ion-ios-partlysunny',
'ion-ios-partlysunny-outline'	=> '&#xf475;  ion-ios-partlysunny-outline',
'ion-ios-pause'	=> '&#xf478;  ion-ios-pause',
'ion-ios-pause-outline'	=> '&#xf477;  ion-ios-pause-outline',
'ion-ios-paw'	=> '&#xf47a;  ion-ios-paw',
'ion-ios-paw-outline'	=> '&#xf479;  ion-ios-paw-outline',
'ion-ios-people'	=> '&#xf47c;  ion-ios-people',
'ion-ios-people-outline'	=> '&#xf47b;  ion-ios-people-outline',
'ion-ios-person'	=> '&#xf47e;  ion-ios-person',
'ion-ios-person-outline'	=> '&#xf47d;  ion-ios-person-outline',
'ion-ios-personadd'	=> '&#xf480;  ion-ios-personadd',
'ion-ios-personadd-outline'	=> '&#xf47f;  ion-ios-personadd-outline',
'ion-ios-photos'	=> '&#xf482;  ion-ios-photos',
'ion-ios-photos-outline'	=> '&#xf481;  ion-ios-photos-outline',
'ion-ios-pie'	=> '&#xf484;  ion-ios-pie',
'ion-ios-pie-outline'	=> '&#xf483;  ion-ios-pie-outline',
'ion-ios-pint'	=> '&#xf486;  ion-ios-pint',
'ion-ios-pint-outline'	=> '&#xf485;  ion-ios-pint-outline',
'ion-ios-play'	=> '&#xf488;  ion-ios-play',
'ion-ios-play-outline'	=> '&#xf487;  ion-ios-play-outline',
'ion-ios-plus'	=> '&#xf48b;  ion-ios-plus',
'ion-ios-plus-empty'	=> '&#xf489;  ion-ios-plus-empty',
'ion-ios-plus-outline'	=> '&#xf48a;  ion-ios-plus-outline',
'ion-ios-pricetag'	=> '&#xf48d;  ion-ios-pricetag',
'ion-ios-pricetag-outline'	=> '&#xf48c;  ion-ios-pricetag-outline',
'ion-ios-pricetags'	=> '&#xf48f;  ion-ios-pricetags',
'ion-ios-pricetags-outline'	=> '&#xf48e;  ion-ios-pricetags-outline',
'ion-ios-printer'	=> '&#xf491;  ion-ios-printer',
'ion-ios-printer-outline'	=> '&#xf490;  ion-ios-printer-outline',
'ion-ios-pulse'	=> '&#xf493;  ion-ios-pulse',
'ion-ios-pulse-strong'	=> '&#xf492;  ion-ios-pulse-strong',
'ion-ios-rainy'	=> '&#xf495;  ion-ios-rainy',
'ion-ios-rainy-outline'	=> '&#xf494;  ion-ios-rainy-outline',
'ion-ios-recording'	=> '&#xf497;  ion-ios-recording',
'ion-ios-recording-outline'	=> '&#xf496;  ion-ios-recording-outline',
'ion-ios-redo'	=> '&#xf499;  ion-ios-redo',
'ion-ios-redo-outline'	=> '&#xf498;  ion-ios-redo-outline',
'ion-ios-refresh'	=> '&#xf49c;  ion-ios-refresh',
'ion-ios-refresh-empty'	=> '&#xf49a;  ion-ios-refresh-empty',
'ion-ios-refresh-outline'	=> '&#xf49b;  ion-ios-refresh-outline',
'ion-ios-reload'	=> '&#xf49d;  ion-ios-reload',
'ion-ios-reverse-camera'	=> '&#xf49f;  ion-ios-reverse-camera',
'ion-ios-reverse-camera-outline'	=> '&#xf49e;  ion-ios-reverse-camera-outline',
'ion-ios-rewind'	=> '&#xf4a1;  ion-ios-rewind',
'ion-ios-rewind-outline'	=> '&#xf4a0;  ion-ios-rewind-outline',
'ion-ios-rose'	=> '&#xf4a3;  ion-ios-rose',
'ion-ios-rose-outline'	=> '&#xf4a2;  ion-ios-rose-outline',
'ion-ios-search'	=> '&#xf4a5;  ion-ios-search',
'ion-ios-search-strong'	=> '&#xf4a4;  ion-ios-search-strong',
'ion-ios-settings'	=> '&#xf4a7;  ion-ios-settings',
'ion-ios-settings-strong'	=> '&#xf4a6;  ion-ios-settings-strong',
'ion-ios-shuffle'	=> '&#xf4a9;  ion-ios-shuffle',
'ion-ios-shuffle-strong'	=> '&#xf4a8;  ion-ios-shuffle-strong',
'ion-ios-skipbackward'	=> '&#xf4ab;  ion-ios-skipbackward',
'ion-ios-skipbackward-outline'	=> '&#xf4aa;  ion-ios-skipbackward-outline',
'ion-ios-skipforward'	=> '&#xf4ad;  ion-ios-skipforward',
'ion-ios-skipforward-outline'	=> '&#xf4ac;  ion-ios-skipforward-outline',
'ion-ios-snowy'	=> '&#xf4ae;  ion-ios-snowy',
'ion-ios-speedometer'	=> '&#xf4b0;  ion-ios-speedometer',
'ion-ios-speedometer-outline'	=> '&#xf4af;  ion-ios-speedometer-outline',
'ion-ios-star'	=> '&#xf4b3;  ion-ios-star',
'ion-ios-star-half'	=> '&#xf4b1;  ion-ios-star-half',
'ion-ios-star-outline'	=> '&#xf4b2;  ion-ios-star-outline',
'ion-ios-stopwatch'	=> '&#xf4b5;  ion-ios-stopwatch',
'ion-ios-stopwatch-outline'	=> '&#xf4b4;  ion-ios-stopwatch-outline',
'ion-ios-sunny'	=> '&#xf4b7;  ion-ios-sunny',
'ion-ios-sunny-outline'	=> '&#xf4b6;  ion-ios-sunny-outline',
'ion-ios-telephone'	=> '&#xf4b9;  ion-ios-telephone',
'ion-ios-telephone-outline'	=> '&#xf4b8;  ion-ios-telephone-outline',
'ion-ios-tennisball'	=> '&#xf4bb;  ion-ios-tennisball',
'ion-ios-tennisball-outline'	=> '&#xf4ba;  ion-ios-tennisball-outline',
'ion-ios-thunderstorm'	=> '&#xf4bd;  ion-ios-thunderstorm',
'ion-ios-thunderstorm-outline'	=> '&#xf4bc;  ion-ios-thunderstorm-outline',
'ion-ios-time'	=> '&#xf4bf;  ion-ios-time',
'ion-ios-time-outline'	=> '&#xf4be;  ion-ios-time-outline',
'ion-ios-timer'	=> '&#xf4c1;  ion-ios-timer',
'ion-ios-timer-outline'	=> '&#xf4c0;  ion-ios-timer-outline',
'ion-ios-toggle'	=> '&#xf4c3;  ion-ios-toggle',
'ion-ios-toggle-outline'	=> '&#xf4c2;  ion-ios-toggle-outline',
'ion-ios-trash'	=> '&#xf4c5;  ion-ios-trash',
'ion-ios-trash-outline'	=> '&#xf4c4;  ion-ios-trash-outline',
'ion-ios-undo'	=> '&#xf4c7;  ion-ios-undo',
'ion-ios-undo-outline'	=> '&#xf4c6;  ion-ios-undo-outline',
'ion-ios-unlocked'	=> '&#xf4c9;  ion-ios-unlocked',
'ion-ios-unlocked-outline'	=> '&#xf4c8;  ion-ios-unlocked-outline',
'ion-ios-upload'	=> '&#xf4cb;  ion-ios-upload',
'ion-ios-upload-outline'	=> '&#xf4ca;  ion-ios-upload-outline',
'ion-ios-videocam'	=> '&#xf4cd;  ion-ios-videocam',
'ion-ios-videocam-outline'	=> '&#xf4cc;  ion-ios-videocam-outline',
'ion-ios-volume-high'	=> '&#xf4ce;  ion-ios-volume-high',
'ion-ios-volume-low'	=> '&#xf4cf;  ion-ios-volume-low',
'ion-ios-wineglass'	=> '&#xf4d1;  ion-ios-wineglass',
'ion-ios-wineglass-outline'	=> '&#xf4d0;  ion-ios-wineglass-outline',
'ion-ios-world'	=> '&#xf4d3;  ion-ios-world',
'ion-ios-world-outline'	=> '&#xf4d2;  ion-ios-world-outline',
'ion-ipad'	=> '&#xf1f9;  ion-ipad',
'ion-iphone'	=> '&#xf1fa;  ion-iphone',
'ion-ipod'	=> '&#xf1fb;  ion-ipod',
'ion-jet'	=> '&#xf295;  ion-jet',
'ion-key'	=> '&#xf296;  ion-key',
'ion-knife'	=> '&#xf297;  ion-knife',
'ion-laptop'	=> '&#xf1fc;  ion-laptop',
'ion-leaf'	=> '&#xf1fd;  ion-leaf',
'ion-levels'	=> '&#xf298;  ion-levels',
'ion-lightbulb'	=> '&#xf299;  ion-lightbulb',
'ion-link'	=> '&#xf1fe;  ion-link',
'ion-load-a'	=> '&#xf29a;  ion-load-a',
'ion-load-b'	=> '&#xf29b;  ion-load-b',
'ion-load-c'	=> '&#xf29c;  ion-load-c',
'ion-load-d'	=> '&#xf29d;  ion-load-d',
'ion-location'	=> '&#xf1ff;  ion-location',
'ion-lock-combination'	=> '&#xf4d4;  ion-lock-combination',
'ion-locked'	=> '&#xf200;  ion-locked',
'ion-log-in'	=> '&#xf29e;  ion-log-in',
'ion-log-out'	=> '&#xf29f;  ion-log-out',
'ion-loop'	=> '&#xf201;  ion-loop',
'ion-magnet'	=> '&#xf2a0;  ion-magnet',
'ion-male'	=> '&#xf2a1;  ion-male',
'ion-man'	=> '&#xf202;  ion-man',
'ion-map'	=> '&#xf203;  ion-map',
'ion-medkit'	=> '&#xf2a2;  ion-medkit',
'ion-merge'	=> '&#xf33f;  ion-merge',
'ion-mic-a'	=> '&#xf204;  ion-mic-a',
'ion-mic-b'	=> '&#xf205;  ion-mic-b',
'ion-mic-c'	=> '&#xf206;  ion-mic-c',
'ion-minus'	=> '&#xf209;  ion-minus',
'ion-minus-circled'	=> '&#xf207;  ion-minus-circled',
'ion-minus-round'	=> '&#xf208;  ion-minus-round',
'ion-model-s'	=> '&#xf2c1;  ion-model-s',
'ion-monitor'	=> '&#xf20a;  ion-monitor',
'ion-more'	=> '&#xf20b;  ion-more',
'ion-mouse'	=> '&#xf340;  ion-mouse',
'ion-music-note'	=> '&#xf20c;  ion-music-note',
'ion-navicon'	=> '&#xf20e;  ion-navicon',
'ion-navicon-round'	=> '&#xf20d;  ion-navicon-round',
'ion-navigate'	=> '&#xf2a3;  ion-navigate',
'ion-network'	=> '&#xf341;  ion-network',
'ion-no-smoking'	=> '&#xf2c2;  ion-no-smoking',
'ion-nuclear'	=> '&#xf2a4;  ion-nuclear',
'ion-outlet'	=> '&#xf342;  ion-outlet',
'ion-paintbrush'	=> '&#xf4d5;  ion-paintbrush',
'ion-paintbucket'	=> '&#xf4d6;  ion-paintbucket',
'ion-paper-airplane'	=> '&#xf2c3;  ion-paper-airplane',
'ion-paperclip'	=> '&#xf20f;  ion-paperclip',
'ion-pause'	=> '&#xf210;  ion-pause',
'ion-person'	=> '&#xf213;  ion-person',
'ion-person-add'	=> '&#xf211;  ion-person-add',
'ion-person-stalker'	=> '&#xf212;  ion-person-stalker',
'ion-pie-graph'	=> '&#xf2a5;  ion-pie-graph',
'ion-pin'	=> '&#xf2a6;  ion-pin',
'ion-pinpoint'	=> '&#xf2a7;  ion-pinpoint',
'ion-pizza'	=> '&#xf2a8;  ion-pizza',
'ion-plane'	=> '&#xf214;  ion-plane',
'ion-planet'	=> '&#xf343;  ion-planet',
'ion-play'	=> '&#xf215;  ion-play',
'ion-playstation'	=> '&#xf30a;  ion-playstation',
'ion-plus'	=> '&#xf218;  ion-plus',
'ion-plus-circled'	=> '&#xf216;  ion-plus-circled',
'ion-plus-round'	=> '&#xf217;  ion-plus-round',
'ion-podium'	=> '&#xf344;  ion-podium',
'ion-pound'	=> '&#xf219;  ion-pound',
'ion-power'	=> '&#xf2a9;  ion-power',
'ion-pricetag'	=> '&#xf2aa;  ion-pricetag',
'ion-pricetags'	=> '&#xf2ab;  ion-pricetags',
'ion-printer'	=> '&#xf21a;  ion-printer',
'ion-pull-request'	=> '&#xf345;  ion-pull-request',
'ion-qr-scanner'	=> '&#xf346;  ion-qr-scanner',
'ion-quote'	=> '&#xf347;  ion-quote',
'ion-radio-waves'	=> '&#xf2ac;  ion-radio-waves',
'ion-record'	=> '&#xf21b;  ion-record',
'ion-refresh'	=> '&#xf21c;  ion-refresh',
'ion-reply'	=> '&#xf21e;  ion-reply',
'ion-reply-all'	=> '&#xf21d;  ion-reply-all',
'ion-ribbon-a'	=> '&#xf348;  ion-ribbon-a',
'ion-ribbon-b'	=> '&#xf349;  ion-ribbon-b',
'ion-sad'	=> '&#xf34a;  ion-sad',
'ion-sad-outline'	=> '&#xf4d7;  ion-sad-outline',
'ion-scissors'	=> '&#xf34b;  ion-scissors',
'ion-search'	=> '&#xf21f;  ion-search',
'ion-settings'	=> '&#xf2ad;  ion-settings',
'ion-share'	=> '&#xf220;  ion-share',
'ion-shuffle'	=> '&#xf221;  ion-shuffle',
'ion-skip-backward'	=> '&#xf222;  ion-skip-backward',
'ion-skip-forward'	=> '&#xf223;  ion-skip-forward',
'ion-social-android'	=> '&#xf225;  ion-social-android',
'ion-social-android-outline'	=> '&#xf224;  ion-social-android-outline',
'ion-social-angular'	=> '&#xf4d9;  ion-social-angular',
'ion-social-angular-outline'	=> '&#xf4d8;  ion-social-angular-outline',
'ion-social-apple'	=> '&#xf227;  ion-social-apple',
'ion-social-apple-outline'	=> '&#xf226;  ion-social-apple-outline',
'ion-social-bitcoin'	=> '&#xf2af;  ion-social-bitcoin',
'ion-social-bitcoin-outline'	=> '&#xf2ae;  ion-social-bitcoin-outline',
'ion-social-buffer'	=> '&#xf229;  ion-social-buffer',
'ion-social-buffer-outline'	=> '&#xf228;  ion-social-buffer-outline',
'ion-social-chrome'	=> '&#xf4db;  ion-social-chrome',
'ion-social-chrome-outline'	=> '&#xf4da;  ion-social-chrome-outline',
'ion-social-codepen'	=> '&#xf4dd;  ion-social-codepen',
'ion-social-codepen-outline'	=> '&#xf4dc;  ion-social-codepen-outline',
'ion-social-css3'	=> '&#xf4df;  ion-social-css3',
'ion-social-css3-outline'	=> '&#xf4de;  ion-social-css3-outline',
'ion-social-designernews'	=> '&#xf22b;  ion-social-designernews',
'ion-social-designernews-outline'	=> '&#xf22a;  ion-social-designernews-outline',
'ion-social-dribbble'	=> '&#xf22d;  ion-social-dribbble',
'ion-social-dribbble-outline'	=> '&#xf22c;  ion-social-dribbble-outline',
'ion-social-dropbox'	=> '&#xf22f;  ion-social-dropbox',
'ion-social-dropbox-outline'	=> '&#xf22e;  ion-social-dropbox-outline',
'ion-social-euro'	=> '&#xf4e1;  ion-social-euro',
'ion-social-euro-outline'	=> '&#xf4e0;  ion-social-euro-outline',
'ion-social-facebook'	=> '&#xf231;  ion-social-facebook',
'ion-social-facebook-outline'	=> '&#xf230;  ion-social-facebook-outline',
'ion-social-foursquare'	=> '&#xf34d;  ion-social-foursquare',
'ion-social-foursquare-outline'	=> '&#xf34c;  ion-social-foursquare-outline',
'ion-social-freebsd-devil'	=> '&#xf2c4;  ion-social-freebsd-devil',
'ion-social-github'	=> '&#xf233;  ion-social-github',
'ion-social-github-outline'	=> '&#xf232;  ion-social-github-outline',
'ion-social-google'	=> '&#xf34f;  ion-social-google',
'ion-social-google-outline'	=> '&#xf34e;  ion-social-google-outline',
'ion-social-googleplus'	=> '&#xf235;  ion-social-googleplus',
'ion-social-googleplus-outline'	=> '&#xf234;  ion-social-googleplus-outline',
'ion-social-hackernews'	=> '&#xf237;  ion-social-hackernews',
'ion-social-hackernews-outline'	=> '&#xf236;  ion-social-hackernews-outline',
'ion-social-html5'	=> '&#xf4e3;  ion-social-html5',
'ion-social-html5-outline'	=> '&#xf4e2;  ion-social-html5-outline',
'ion-social-instagram'	=> '&#xf351;  ion-social-instagram',
'ion-social-instagram-outline'	=> '&#xf350;  ion-social-instagram-outline',
'ion-social-javascript'	=> '&#xf4e5;  ion-social-javascript',
'ion-social-javascript-outline'	=> '&#xf4e4;  ion-social-javascript-outline',
'ion-social-linkedin'	=> '&#xf239;  ion-social-linkedin',
'ion-social-linkedin-outline'	=> '&#xf238;  ion-social-linkedin-outline',
'ion-social-markdown'	=> '&#xf4e6;  ion-social-markdown',
'ion-social-nodejs'	=> '&#xf4e7;  ion-social-nodejs',
'ion-social-octocat'	=> '&#xf4e8;  ion-social-octocat',
'ion-social-pinterest'	=> '&#xf2b1;  ion-social-pinterest',
'ion-social-pinterest-outline'	=> '&#xf2b0;  ion-social-pinterest-outline',
'ion-social-python'	=> '&#xf4e9;  ion-social-python',
'ion-social-reddit'	=> '&#xf23b;  ion-social-reddit',
'ion-social-reddit-outline'	=> '&#xf23a;  ion-social-reddit-outline',
'ion-social-rss'	=> '&#xf23d;  ion-social-rss',
'ion-social-rss-outline'	=> '&#xf23c;  ion-social-rss-outline',
'ion-social-sass'	=> '&#xf4ea;  ion-social-sass',
'ion-social-skype'	=> '&#xf23f;  ion-social-skype',
'ion-social-skype-outline'	=> '&#xf23e;  ion-social-skype-outline',
'ion-social-snapchat'	=> '&#xf4ec;  ion-social-snapchat',
'ion-social-snapchat-outline'	=> '&#xf4eb;  ion-social-snapchat-outline',
'ion-social-tumblr'	=> '&#xf241;  ion-social-tumblr',
'ion-social-tumblr-outline'	=> '&#xf240;  ion-social-tumblr-outline',
'ion-social-tux'	=> '&#xf2c5;  ion-social-tux',
'ion-social-twitch'	=> '&#xf4ee;  ion-social-twitch',
'ion-social-twitch-outline'	=> '&#xf4ed;  ion-social-twitch-outline',
'ion-social-twitter'	=> '&#xf243;  ion-social-twitter',
'ion-social-twitter-outline'	=> '&#xf242;  ion-social-twitter-outline',
'ion-social-usd'	=> '&#xf353;  ion-social-usd',
'ion-social-usd-outline'	=> '&#xf352;  ion-social-usd-outline',
'ion-social-vimeo'	=> '&#xf245;  ion-social-vimeo',
'ion-social-vimeo-outline'	=> '&#xf244;  ion-social-vimeo-outline',
'ion-social-whatsapp'	=> '&#xf4f0;  ion-social-whatsapp',
'ion-social-whatsapp-outline'	=> '&#xf4ef;  ion-social-whatsapp-outline',
'ion-social-windows'	=> '&#xf247;  ion-social-windows',
'ion-social-windows-outline'	=> '&#xf246;  ion-social-windows-outline',
'ion-social-wordpress'	=> '&#xf249;  ion-social-wordpress',
'ion-social-wordpress-outline'	=> '&#xf248;  ion-social-wordpress-outline',
'ion-social-yahoo'	=> '&#xf24b;  ion-social-yahoo',
'ion-social-yahoo-outline'	=> '&#xf24a;  ion-social-yahoo-outline',
'ion-social-yen'	=> '&#xf4f2;  ion-social-yen',
'ion-social-yen-outline'	=> '&#xf4f1;  ion-social-yen-outline',
'ion-social-youtube'	=> '&#xf24d;  ion-social-youtube',
'ion-social-youtube-outline'	=> '&#xf24c;  ion-social-youtube-outline',
'ion-soup-can'	=> '&#xf4f4;  ion-soup-can',
'ion-soup-can-outline'	=> '&#xf4f3;  ion-soup-can-outline',
'ion-speakerphone'	=> '&#xf2b2;  ion-speakerphone',
'ion-speedometer'	=> '&#xf2b3;  ion-speedometer',
'ion-spoon'	=> '&#xf2b4;  ion-spoon',
'ion-star'	=> '&#xf24e;  ion-star',
'ion-stats-bars'	=> '&#xf2b5;  ion-stats-bars',
'ion-steam'	=> '&#xf30b;  ion-steam',
'ion-stop'	=> '&#xf24f;  ion-stop',
'ion-thermometer'	=> '&#xf2b6;  ion-thermometer',
'ion-thumbsdown'	=> '&#xf250;  ion-thumbsdown',
'ion-thumbsup'	=> '&#xf251;  ion-thumbsup',
'ion-toggle'	=> '&#xf355;  ion-toggle',
'ion-toggle-filled'	=> '&#xf354;  ion-toggle-filled',
'ion-transgender'	=> '&#xf4f5;  ion-transgender',
'ion-trash-a'	=> '&#xf252;  ion-trash-a',
'ion-trash-b'	=> '&#xf253;  ion-trash-b',
'ion-trophy'	=> '&#xf356;  ion-trophy',
'ion-tshirt'	=> '&#xf4f7;  ion-tshirt',
'ion-tshirt-outline'	=> '&#xf4f6;  ion-tshirt-outline',
'ion-umbrella'	=> '&#xf2b7;  ion-umbrella',
'ion-university'	=> '&#xf357;  ion-university',
'ion-unlocked'	=> '&#xf254;  ion-unlocked',
'ion-upload'	=> '&#xf255;  ion-upload',
'ion-usb'	=> '&#xf2b8;  ion-usb',
'ion-videocamera'	=> '&#xf256;  ion-videocamera',
'ion-volume-high'	=> '&#xf257;  ion-volume-high',
'ion-volume-low'	=> '&#xf258;  ion-volume-low',
'ion-volume-medium'	=> '&#xf259;  ion-volume-medium',
'ion-volume-mute'	=> '&#xf25a;  ion-volume-mute',
'ion-wand'	=> '&#xf358;  ion-wand',
'ion-waterdrop'	=> '&#xf25b;  ion-waterdrop',
'ion-wifi'	=> '&#xf25c;  ion-wifi',
'ion-wineglass'	=> '&#xf2b9;  ion-wineglass',
'ion-woman'	=> '&#xf25d;  ion-woman',
'ion-wrench'	=> '&#xf2ba;  ion-wrench',
'ion-xbox'	=> '&#xf30c;  ion-xbox'


);
	}
}